@@ -2,7 +2,7 @@
   ZynAddSubFX - a software synthesizer
  
   Config.h - Configuration file functions
-  Copyright (C) 2003 Nasca Octavian Paul
+  Copyright (C) 2003-2005 Nasca Octavian Paul
   Author: Nasca Octavian Paul
 
   This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,8 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 #include "../globals.h"
+#define MAX_STRING_SIZE 4000
+#define MAX_BANK_ROOT_DIRS 100
 
 class Config{
     public:
@@ -33,6 +35,15 @@ class Config{
 	    int SampleRate,SoundBufferSize,OscilSize,SwapStereo;
 	    int WindowsWaveOutId,WindowsMidiInId;
 	    int BankUIAutoClose;
+	    int DumpNotesToFile,DumpAppend;
+	    int GzipCompression;
+	    int Interpolation;
+	    char *DumpFile;
+	    char *bankRootDirList[MAX_BANK_ROOT_DIRS],*currentBankDir;
+	    char *presetsDirList[MAX_BANK_ROOT_DIRS];
+	    int CheckPADsynth;
+	    int UserInterfaceMode;
+	    int VirKeybLayout;
 	} cfg;
 	int winwavemax,winmidimax;//number of wave/midi devices on Windows
 	int maxstringsize;
@@ -41,6 +52,11 @@ class Config{
 	    char *name;
 	};
 	winmidionedevice *winmididevices;
+
+	void clearbankrootdirlist();
+	void clearpresetsdirlist();
+	void init();
+	void save();
 	
     private:
 	void readConfig(char *filename);
