@@ -23,6 +23,7 @@
 #define JACK_AUDIO_OUTPUT_H
 
 #include <jack/jack.h>
+
 #include "../globals.h"
 #include "../Misc/Master.h"
 
@@ -37,7 +38,7 @@
 
 
 
-void JACKaudiooutputinit(Master *master_);
+bool JACKaudiooutputinit(Master *master_);
 void JACKfinish();
 
 #endif
